CREATE LANGUAGE "plpgsql";

CREATE OR REPLACE FUNCTION delete_polling_answer_userip()
  RETURNS trigger AS
$BODY$
 BEGIN  
 DELETE FROM polling_answer  WHERE query_id = OLD.id;
 DELETE FROM polling_userip  WHERE query_id = OLD.id; 
 RETURN NEW;
 END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION delete_polling_answer_userip()
  OWNER TO postgres;
COMMENT ON FUNCTION delete_polling_answer_userip() IS 'Remove the relationship of the tables polling_answer and polling_userip';


CREATE OR REPLACE FUNCTION update_polling_max_votes()
  RETURNS trigger AS
$BODY$
 BEGIN 
 
 IF (NEW.answer_val != OLD.answer_val) THEN   
 UPDATE polling_query SET max_votes = (select max(answer_val) from polling_answer where query_id = NEW.query_id) WHERE  id = NEW.query_id; 
 UPDATE polling_query SET total_votes = (select sum(answer_val) from polling_answer where query_id = NEW.query_id) WHERE  id = NEW.query_id;
 END IF;

RETURN NEW;
 END;
$BODY$
  LANGUAGE plpgsql VOLATILE
  COST 100;
ALTER FUNCTION update_polling_max_votes()
  OWNER TO postgres;
  


CREATE TABLE polling_answer
(
  id serial NOT NULL,
  query_id integer NOT NULL DEFAULT 0,
  answer_val integer NOT NULL DEFAULT 0,
  answer character varying(100) NOT NULL DEFAULT ''::character varying,
  color character varying(7) NOT NULL DEFAULT ''::character varying,
  CONSTRAINT polling_id_gl PRIMARY KEY (id )
)
WITH (
  OIDS=FALSE
);
ALTER TABLE polling_answer
  OWNER TO postgres;

CREATE INDEX polling_answer_index_1
  ON polling_answer
  USING btree
  (id );

CREATE INDEX polling_answer_index_2
  ON polling_answer
  USING btree
  (query_id );

CREATE TRIGGER "UPD"
  AFTER UPDATE
  ON polling_answer
  FOR EACH ROW
  EXECUTE PROCEDURE update_polling_max_votes();
  

  
CREATE TABLE polling_query
(
  id serial NOT NULL,
  query character varying(100) NOT NULL DEFAULT ''::character varying,
  width integer NOT NULL DEFAULT 0,
  user_sel_method integer NOT NULL DEFAULT 0,
  max_votes integer NOT NULL DEFAULT 0,
  total_votes integer NOT NULL DEFAULT 0,
  activate boolean NOT NULL DEFAULT true,
  show_results integer NOT NULL DEFAULT 0
)
WITH (
  OIDS=FALSE
);
ALTER TABLE polling_query
  OWNER TO postgres;

CREATE INDEX polling_query_index_1
  ON polling_query
  USING btree
  (id );

CREATE INDEX polling_query_index_2
  ON polling_query
  USING btree
  (id , activate );

CREATE TRIGGER "DEL"
  AFTER DELETE
  ON polling_query
  FOR EACH ROW
  EXECUTE PROCEDURE delete_polling_answer_userip();


CREATE TABLE polling_userip
(
  query_id integer NOT NULL DEFAULT 0,
  userip character varying(15) NOT NULL DEFAULT ''::character varying,
  CONSTRAINT pk_userip_queryid PRIMARY KEY (query_id , userip )
)
WITH (
  OIDS=FALSE
);
ALTER TABLE polling_userip
  OWNER TO postgres;

CREATE INDEX polling_userip_index_1
  ON polling_userip
  USING btree
  (query_id , userip );
  
  
  
  
  
  